import _ = require('lodash');

/**
 * @constructor
 * 通过object传过来,名称需要匹配Param
 * @param {Array} like_prop 范围查询字段数组
 */
export class SearchBase {
  constructor({ like_prop = [] }) {
    this.like_prop = like_prop;
  }
  /** 模糊查询字段数组 */
  like_prop: Array<string>;

  /**
   * 此处将字段转换为使用的方式
   */
  getFilter() {
    const exclude = ['like_prop'];
    const keys = Object.keys(this).filter(f => !exclude.includes(f));
    const result = {};
    for (const i of keys) {
      const value = this[i];
      // 值不存在或者为空字符串,过滤掉
      if (!value || value === '') continue;
      if (this.like_prop.includes(i)) {
        // 处理模糊查询
        result[i] = new RegExp(value);
      } else if (i.includes('@')) {
        // 处理范围查询
        const arr = i.split('@');
        const prop = _.head(arr);
        const pos = _.last(arr);
        const pd = _.get(result, prop, {});
        if (pos === 'start') {
          Object.assign(pd, { $gte: value });
        } else if (pos === 'end') {
          Object.assign(pd, { $lte: value });
        } else continue;
        result[prop] = pd;
      } else {
        // 正常处理
        result[i] = value;
      }
    }
    return result;
  }
}
